/*
 * themedatastorage.cpp
 *
 *  Created on: 27.5.2010
 *      Author: jlep
 */

#include <QFont>
#include <QPixmap>
#include <QLinearGradient>

#include "wpcommongeometry.h"
#include "themedatastorage.h"
#include "utils.h"

ThemeData::ThemeData() :
      iTabGradientBrush(NULL),
      iTabFont(NULL),
      iListContentFont(NULL),
      iListInfoFont(NULL)
{
    iIcons.clear();
}

ThemeData::~ThemeData()
{
    delete iTabGradientBrush;
    delete iTabFont;
    
    delete iListContentFont;
    delete iListInfoFont;

    iIcons.clear();
}

void ThemeData::Init()
{
    // Tabs
    iTabBarHeight = Utils::smallScreen() ? 27 : 60;
    iMinTabSize = Utils::smallScreen() ? QSizeF(20, 10) :
                                         QSizeF(80, 55); 
    QLinearGradient ql(0, 0, 0, iTabBarHeight);
    ql.setColorAt(0.0, QColor(238,238,238));
    ql.setColorAt(0.5, QColor(216,216,216));
    ql.setColorAt(1.0, QColor(203,203,203));
    iTabGradientBrush = new QBrush(ql);
    iTabFont = new QFont("Arial");
    iTabFont->setPixelSize(Utils::smallScreen() ? 12 : 10);    
    
    iIconSheet = QPixmap(":/images/icons32-vs.png");
    iBwIconSheet = QPixmap(":/images/icons32-vs-bw.png");

    iContextMenuIcons.clear();
    iContextMenuIcons.append(QPixmap(":/images/approve.png"));
    iContextMenuIcons.append(QPixmap(":/images/edit.png"));
    iContextMenuIcons.append(QPixmap(":/images/open.png"));
    iContextMenuIcons.append(QPixmap(":/images/remove.png"));
    iContextMenuIcons.append(QPixmap(":/images/reply.png"));
    iContextMenuIcons.append(QPixmap(":/images/spam.png"));
    iContextMenuIcons.append(QPixmap(":/images/view.png"));
    
    // Lists
	
    iListContentFont = new QFont("Arial");
    iListContentFont->setPixelSize(Utils::smallScreen() ? 14 : 19);
	
	iListInfoFont = new QFont("Arial");
	iListInfoFont->setPixelSize(Utils::smallScreen() ? 11 : 14);
	
	iListItemInternalPadding = Utils::smallScreen() ? 3 : 5;
	iListItemContentVMargin = Utils::smallScreen() ? 6 : 9;
    iListItemContentHMargin = Utils::smallScreen() ? 8 : 14;
	
	iListShowCommentIcons = !Utils::smallScreen();
	
    #ifdef Q_WS_MAEMO_5
    iListTitleMargin = 8;
	iListTitleHeight = 26;
    #else
    iListTitleMargin = 2;
	iListTitleHeight = Utils::smallScreen() ? 18 : 26;
    #endif 
	
    // XXX: never used
	// iListItemSpacing = Utils::smallScreen() ? 3 : 5;
	
	iListButtonQss =
                "QPushButton {"
                     // XXX: broken, background overflows borders: 
					 // "margin: 0 9px;" 
					 "border: none;"
                "}";
}

QPixmap const & ThemeData::GetIcon(QPixmap const & source, IconMap & map, TIconSheet icon)
{
    // Lazy initialization for icons, don't do any extra work
    if(!map.contains(icon)) {
        const int iconCount = 12;
        const int iconWidth = source.width() / iconCount;
        map[icon] = source.copy(icon * iconWidth, 0, iconWidth, source.height());
    }
    
    return map[icon];
}
